@@ -7,6 +7,7 @@ import sys
 
 from .jrnl import run
 from .args import parse_args
+from .exception import JrnlError
 
 
 def configure_logger(debug=False):
@@ -33,5 +34,9 @@ def cli(manual_args=None):
 
         return run(args)
 
+    except JrnlError as e:
+        print(e.message, file=sys.stderr)
+        return 1
+
     except KeyboardInterrupt:
         return 1
