@@ -1,18 +1,23 @@
 import logging
 import os
-import shlex
 import subprocess
 import sys
 import tempfile
 import textwrap
+from pathlib import Path
 
 from .color import ERROR_COLOR
 from .color import RESET_COLOR
 from .os_compat import on_windows
+from .os_compat import split_args
 
 
 def get_text_from_editor(config, template=""):
-    filehandle, tmpfile = tempfile.mkstemp(prefix="jrnl", text=True, suffix=".txt")
+    suffix = ".jrnl"
+    if config["template"]:
+        template_filename = Path(config["template"]).name
+        suffix = "-" + template_filename
+    filehandle, tmpfile = tempfile.mkstemp(prefix="jrnl", text=True, suffix=suffix)
     os.close(filehandle)
 
     with open(tmpfile, "w", encoding="utf-8") as f:
@@ -20,7 +25,7 @@ def get_text_from_editor(config, template=""):
             f.write(template)
 
     try:
-        subprocess.call(shlex.split(config["editor"], posix=on_windows) + [tmpfile])
+        subprocess.call(split_args(config["editor"]) + [tmpfile])
     except Exception as e:
         error_msg = f"""
         {ERROR_COLOR}{str(e)}{RESET_COLOR}
@@ -42,7 +47,7 @@ def get_text_from_editor(config, template=""):
 
 
 def get_text_from_stdin():
-    _how_to_quit = "Ctrl+z and then Enter" if on_windows else "Ctrl+d"
+    _how_to_quit = "Ctrl+z and then Enter" if on_windows() else "Ctrl+d"
     print(
         f"[Writing Entry; on a blank line, press {_how_to_quit} to finish writing]\n",
         file=sys.stderr,
